You are debugging a Python file. The file has a bug.
In each step, you can:
1. Read the file (action: "read")
2. Edit the file (action: the corrected code)
3. Run tests (action: "test")

Fix the bug so all tests pass.
